============
Bibliography
============

.. [Bourbaki46] Nicolas Bourbaki. *Lie Groups and Lie Algebras: Chapters 4-6*.
   Springer, reprint edition, 1998.

.. [BumpNakasuji2010] \D. Bump and M. Nakasuji. *Casselman's basis of
   Iwahori vectors and the Bruhat order*. :arxiv:`1002.2996`,
   :arxiv:`1002.2996`.

.. [BumpSchilling2017] \D. Bump and A. Schilling, *Crystal bases:
   representations and combinatorics*, World Scientific, 2017.

.. [Carrell1994] \J. B. Carrell. The Bruhat graph of a Coxeter group, a
   conjecture of Deodhar, and rational smoothness of Schubert varieties. In
   *Algebraic Groups and Their Generalizations: Classical Methods*,
   AMS Proceedings of Symposia in Pure Mathematics, 56, 53--61, 1994.

.. [Deodhar1977] \V. V. Deodhar. Some characterizations of Bruhat
   ordering on a Coxeter group and determination of the relative
   Moebius function. Inventiones Mathematicae, 39(2):187--198, 1977.

.. [Dyer1993] \M. J. Dyer. The nil Hecke ring and Deodhar's conjecture
   on Bruhat intervals. Inventiones Mathematicae, 111(1):571--574, 1993.

.. [Dynkin1952] \E. B. Dynkin,
   Semisimple subalgebras of semisimple Lie algebras. (Russian)
   Mat. Sbornik N.S. 30(72):349–462, 1952.

.. [FauserEtAl2006] \B. Fauser, P. D. Jarvis, R. C. King, and
   B. G. Wybourne. New branching rules induced by plethysm. *Journal of
   Physics A*. 39(11):2611--2655, 2006.

.. [Fulton1997] \W. Fulton. *Young Tableaux*. Cambridge University
   Press, 1997.

.. [FourierEtAl2009] \G. Fourier, M. Okado, A. Schilling.
   Kirillov--Reshetikhin crystal for nonexceptional types.
   *Advances in Mathematics*, 222:1080--1116, 2009.

.. [FourierEtAl2010] \G. Fourier, M. Okado, A. Schilling.
   Perfectness of Kirillov-Reshetikhin crystals for nonexceptional types.
   *Contemp. Math.*, 506:127--143, 2010.

.. [HatayamaEtAl2001] \G. Hatayama, A. Kuniba, M. Okado, T. Takagi, Z. Tsuboi.
   Paths, crystals and fermionic formulae.
   in MathPhys Odyssey 2001, in : Prog. Math. Phys., vol 23, Birkhauser Boston,
   Boston, MA 2002, pp. 205--272.

.. [HainesEtAl2009] \T. J. Haines, R. E. Kottwitz, and
   A. Prasad. *Iwahori-Hecke Algebras*. :arxiv:`math/0309168`.

.. [HongKang2002] \J. Hong and S.-J. Kang. *Introduction to Quantum
   Groups and Crystal Bases*. AMS Graduate Studies in Mathematics,
   American Mathematical Society, 2002.

.. [HongLee2008] \J. Hong and H. Lee. Young tableaux and crystal
   `B(\infty)` for finite simple Lie algebras. *J. Algebra*,
   320:3680--3693, 2008.

.. [HoweEtAl2005] \R. Howe, E.-C.Tan, and J. F. Willenbring. Stable
   branching rules for classical symmetric pairs. *Transactions of the
   American Mathematical Society*, 357(4):1601--1626, 2005.

.. [Iwahori1964] \N. Iwahori. On the structure of a Hecke ring of a
   Chevalley group over a finite field. *J. Fac. Sci. Univ. Tokyo
   Sect. I*, 10:215--236, 1964.

.. [JayneMisra2014] \R. Jayne and K. Misra,
   On multiplicities of maximal weights of
   `\widehat{sl}(n)`-modules. Algebr. Represent. Theory 17 (2014), no. 4,
   1303–1321. :arxiv:`1309.4969`.

.. [Jimbo1986] \M. A. Jimbo. `q`-analogue of `U(\mathfrak{gl}(N+1))`,
   Hecke algebra, and the Yang-Baxter equation.
   *Lett. Math. Phys*, 11(3):247--252, 1986.

.. [JonesEtAl2010] \B. Jones, A. Schilling.
   Affine structures and a tableau model for E_6 crystals
   *J. Algebra*, 324:2512-2542, 2010.

.. [Joseph1995] \A. Joseph. *Quantum Groups and Their Primitive Ideals*.
   Springer-Verlag, 1995.

.. [Kac] Victor G. Kac. *Infinite Dimensional Lie algebras*,
   Cambridge University Press, third edition, 1994.

.. [KacPeterson] Kac and Peterson. *Infinite-dimensional Lie algebras,
   theta functions and modular forms*. Adv. in Math. 53 (1984),
   no. 2, 125-264.

.. [KKMMNN1992] S-J. Kang, M. Kashiwara, K. C. Misra, T. Miwa,
   T. Nakashima, A. Nakayashiki.
   Affine crystals and vertex models.
   *Int. J. Mod. Phys.* A 7 (suppl. 1A): 449--484, 1992.

.. [KKS2007] \S.-J. Kang, J.-A. Kim, and D.-U. Shin.
   Modified Nakajima monomials and the crystal `B(\infty)`.
   *J. Algebra*, **308** (2007), 524-535.

.. [Kashiwara1993] \M. Kashiwara. The crystal base and Littelmann's refined
   Demazure character formula. *Duke Math. J.*, 71(3):839--858, 1993.

.. [Kashiwara1995] \M. Kashiwara. On crystal bases. Representations of
   groups (Banff, AB, 1994), 155--197, CMS Conference Proceedings, 16,
   American Mathematical Society, Providence, RI, 1995.

.. [KashiwaraNakashima1994] \M. Kashiwara and T. Nakashima. Crystal
   graphs for representations of the `q`-analogue of classical Lie
   algebras. *Journal Algebra*, 165(2):295--345, 1994.

.. [KMPS] Kass, Moody, Patera and Slansky, *Affine Lie algebras,
   weight multiplicities, and branching rules*. Vols. 1, 2. University
   of California Press, Berkeley, CA, 1990.

.. [KimShin2010] \J.-A. Kim and D.-U. Shin. Generalized Young walls and
   crystal bases for quantum affine algebra of type `A`. *Proc. Amer.
   Math. Soc.*, 138(11):3877--3889, 2010.

.. [KimLeeOh2017] Jang Soo Kim, Kyu-Hwan Lee and Se-Jin Oh,
   Weight multiplicities and Young tableaux through affine crystals.
   :arxiv:`1703.10321` (2017).

.. [King1975] \R. C. King. Branching rules for classical Lie groups
   using tensor and spinor methods. *Journal of Physics A*,
   8:429--449, 1975.

.. [Knuth1970] \D. Knuth. Permutations, matrices, and generalized Young
   tableaux. *Pacific Journal of Mathematics*, 34(3):709--727, 1970.

.. [Knuth1998] \D. Knuth. *The Art of Computer
   Programming. Volume 3. Sorting and Searching*. Addison Wesley
   Longman, 1998.

.. [LNSSS14I] \C. Lenart, S. Naito, D. Sagaki, A. Schilling, and M. Shimozono.
   A uniform model for Kirillov-Reshetikhin crystals I: Lifting the
   parabolic quantum Bruhat graph. (2014) :arxiv:`1211.2042`

.. [LNSSS14II] \C. Lenart, S. Naito, D. Sagaki, A. Schilling, and M. Shimozono.
   A uniform model for Kirillov-Reshetikhin crystals II: Alcove model,
   path model, and `P = X`. (2014) :arxiv:`1402.2203`

.. [L1995] \P. Littelmann. *Paths and root operators in representation theory*.
   Ann. of Math. (2) 142 (1995), no. 3, 499-525.

.. [Macdonald2003] \I. Macdonald.
   *Affine Hecke algebras and orthogonal polynomials*, Cambridge, 2003.

.. [McKayPatera1981] \W. G. McKay and J. Patera. *Tables of Dimensions,
   Indices and Branching Rules for Representations of Simple Lie
   Algebras*. Marcel Dekker, 1981.

.. [OkadoSchilling2008] \M. Okado, A.Schilling. Existence of crystal bases for
   Kirillov--Reshetikhin crystals for nonexceptional types.
   *Representation Theory* 12:186--207, 2008.

.. [Seitz1991] \G. Seitz,
   Maximal subgroups of exceptional algebraic groups.
   Mem. Amer. Math. Soc. 90 (1991), no. 441.

.. [Rubenthaler2008] \H. Rubenthaler,
   The (A2,G2) duality in E6, octonions and the triality principle.
   Trans. Amer. Math. Soc. 360 (2008), no. 1, 347–367.

.. [SalisburyScrimshaw2015] \B. Salisbury and T. Scrimshaw. A rigged
   configuration model for `B(\infty)`. *J. Combin. Theory Ser. A*,
   133:29--57, 2015.

.. [Schilling2006] \A. Schilling. Crystal structure on rigged configurations.
   *Int. Math. Res. Not.*, Volume 2006. (2006) Article ID 97376. Pages 1-27.

.. [SchillingTingley2011] \A. Schilling, P. Tingley.
   *Demazure crystals, Kirillov-Reshetikhin crystals, and the energy function*.
   preprint :arxiv:`1104.2359`

.. [Stanley1999] \R. P. Stanley. *Enumerative Combinatorics, Volume
   2*. Cambridge University Press, 1999.

.. [Testerman1989] Testerman, Donna M.
   A construction of certain maximal subgroups of the algebraic groups E6 and F4.
   J. Algebra 122 (1989), no. 2, 299–322.

.. [Testerman1992] Testerman, Donna M. The construction of the maximal A1's in
   the exceptional algebraic groups. Proc. Amer. Math. Soc. 116 (1992), no. 3, 635–644.
